@@ -1,4 +1,5 @@
 from time import perf_counter
+from typing import Generator
 
 from PyQt5 import QtCore, QtWidgets
 from PyQt5.QtMultimedia import QSoundEffect
@@ -22,6 +23,7 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
         self,
         highscore_handler: HighscoreDataHandler,
         stacked_widget: QtWidgets.QStackedWidget,
+        key_sounds_rotator: Generator[QSoundEffect, None, None],
         *args,
         **kwargs,
     ):
@@ -33,6 +35,7 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
         self.setupUi(self)
 
         self.lineInput.textChanged.connect(self._on_input_text_changed)
+        self.lineInput.textChanged.connect(lambda: next(key_sounds_rotator).play())
         self.buttonNewText.clicked.connect(self.on_clicked_new)
         self.buttonRestart.clicked.connect(self.on_clicked_restart)
 
@@ -68,13 +71,6 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
 
         self.colours: dict[str, str] = colours
 
-    def set_key_sound(self, key_sound: QSoundEffect) -> None:
-        """
-        Set the sound to be played on a keystroke (should be a QSoundEffect object).
-        """
-
-        self.key_sound = key_sound
-
     # Private methods
     def _set_main_text(self) -> None:
         """
@@ -94,6 +90,10 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
 
     def _calculate_score(self, accuracy: int) -> int:
         """Returns wpm score after calculations including accuracy."""
+
+        if accuracy < 75:
+            return 0
+
         self.start_time: float
 
         seconds: float = perf_counter() - self.start_time
@@ -183,8 +183,6 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
 
         self.results_window = results.ResultsWindow()
 
-        self.results_window.setWindowIcon(self.windowIcon())
-
         self.results_window.labelAccuracy.setText(f"{str(self.accuracy)}%")
         self.results_window.labelSpeed.setText(f"{str(self.wpm)} WPM")
 
@@ -209,6 +207,7 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
         self._create_results_window()
 
         self._show_results_window()
+        self.results_window.buttonNext.setFocus()
 
         if self.isMaximized():
             self.results_window.setWindowState(QtCore.Qt.WindowMaximized)
@@ -233,9 +232,6 @@ class TypingWindow(QtWidgets.QWidget, typing_window.Ui_typingWindow):
             self.timer.start()
             self.start_time = perf_counter()
 
-        # Try to play key sound effect, if it exists
-        self.key_sound.play()
-
         # Set label text to rich text so typed characters are highlighted
         # based on whether they match self.text
         rich_text = self._get_rich_text(input_text)
